==> elasticsearch-java-8.9.0-sources.jar: co/elastic/clients/elasticsearch/_types/query_dsl/RangeRelation.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types.query_dsl;

import co.elastic.clients.json.JsonEnum;
import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;

/**
 *
 * @see <a href=
 *      "../../doc-files/api-spec.html#_types.query_dsl.RangeRelation">API
 *      specification</a>
 */
@JsonpDeserializable
public enum RangeRelation implements JsonEnum {
	Within("within"),

	Contains("contains"),

	Intersects("intersects"),

	;

	private final String jsonValue;

	RangeRelation(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final JsonEnum.Deserializer<RangeRelation> _DESERIALIZER = new JsonEnum.Deserializer<>(
			RangeRelation.values());
}

==> elasticsearch-java-8.11.3-sources.jar: co/elastic/clients/elasticsearch/_types/query_dsl/RangeRelation.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types.query_dsl;

import co.elastic.clients.json.JsonEnum;
import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;

/**
 *
 * @see <a href=
 *      "../../doc-files/api-spec.html#_types.query_dsl.RangeRelation">API
 *      specification</a>
 */
@JsonpDeserializable
public enum RangeRelation implements JsonEnum {
	/**
	 * Matches documents with a range field value entirely within the query’s range.
	 */
	Within("within"),

	/**
	 * Matches documents with a range field value that entirely contains the query’s
	 * range.
	 */
	Contains("contains"),

	/**
	 * Matches documents with a range field value that intersects the query’s range.
	 */
	Intersects("intersects"),

	;

	private final String jsonValue;

	RangeRelation(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final JsonEnum.Deserializer<RangeRelation> _DESERIALIZER = new JsonEnum.Deserializer<>(
			RangeRelation.values());
}
